---
name: Bug report
about: buat report untuk membantu kita dalam menyelesaikan masalah pada repository
title: BUG
labels: bug
assignees: slowy07

---

## Masalah

<!-- jelaskan masalah kamu secara detail -->

## Screenshots atau contoh error

<!-- copy paste contoh errornya disini atau kirim screenshot dengan copy paste gambar -->

```
pesan error
```

## Desktop (please complete the following information):

<!-- Ganti sesuai yang digunakan. -->

- OS: `linux/windows/macOS`
- Python: `version`

terima kasih
